#[repr(C)]pub struct FrameOptionsGL {Show 14 fields
pub clear_history: bool,
pub frame_direction: i32,
pub rotation: u32,
pub total_subframes: u32,
pub current_subframe: u32,
pub aspect_ratio: f32,
pub frames_per_second: f32,
pub frametime_delta: u32,
pub color_space: __ColorSpace,
pub brightness_nits: f32,
pub expand_gamut: u32,
pub gyroscope: [f32; 3],
pub accelerometer: [f32; 3],
pub accelerometer_rest: [f32; 3],
}Expand description
Options for each frame.
Fields
clear_history: boolWhether or not to clear the history buffers.
frame_direction: i32The direction of rendering. -1 indicates that the frames are played in reverse order.
rotation: u32The rotation of the output. 0 = 0deg, 1 = 90deg, 2 = 180deg, 3 = 270deg.
total_subframes: u32The total number of subframes ran. Default is 1.
current_subframe: u32The current sub frame. Default is 1.
aspect_ratio: f32The expected aspect ratio of the source image.
This can differ from the actual aspect ratio of the source image.
The default is 0 which will automatically infer the ratio from the source image.
frames_per_second: f32The original frames per second of the source. Default is 1.
frametime_delta: u32Time in milliseconds between the current and previous frame. Default is 0.
color_space: __ColorSpaceTarget color space bound to the shader HDRMode uniform. Must
match the host swapchain color space. Default is
ColorSpace::Sdr.
brightness_nits: f32HDR SDR reference white in nits, bound to the shader BrightnessNits uniform.
Default is 200.0. Only meaningful when the chain’s HDR mode is non-zero.
expand_gamut: u32Gamut expansion mode bound to the shader ExpandGamut uniform. Default is 0.
gyroscope: [f32; 3]Bound to the shader Gyroscope (vec3) uniform. Default is [0, 0, 0].
accelerometer: [f32; 3]Bound to the shader Accelerometer (vec3) uniform. Default is [0, 0, 0].
accelerometer_rest: [f32; 3]Bound to the shader AccelerometerRest (vec3) uniform. Default is [0, 0, 0].